formattools.get_context_setting_format_contributions
====================================================

.. autofunction:: abjad.tools.formattools.get_context_setting_format_contributions.get_context_setting_format_contributions
   :noindex:
